==> lxqt-notificationd_0.14.0.orig.tar.xz: lxqt-notificationd-0.14.0/config/translations/lxqt-config-notificationd_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Odstęp:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Czas trwania</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Niektóre powiadomienia mają swój własny czas trwania.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Domyślny czas trwania:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="127"/>
        <source>Unattended Notifications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>How many to save:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <location filename="../advancedsettings.ui" line="159"/>
        <source>Application name is on the top of notification.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="152"/>
        <source>Ignore these applications:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="162"/>
        <source>app1,app2,app3</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Ustawienia ogólne</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Pozycja na ekranie</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="56"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Uwaga:&lt;/b&gt; Żadna usługa powiadomień nie jest uruchomiona.
Zostanie użyty zamiennik.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Uwaga:&lt;/b&gt; Inny daemon powiadomień (%1) jest uruchomiony.
Te ustawienia nie będą miały żadnego wpływu na jego działanie!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="112"/>
        <source>Notification demo </source>
        <translation>Podgląd powiadomienia </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="113"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>To jest testowe powiadomienie.
Wszystkie powiadomienia LXQt będą teraz pojawiać się tutaj.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Powiadomienia ekranowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Zaawansowane</translation>
    </message>
</context>
</TS>

==> lxqt-notificationd_0.14.1.orig.tar.xz: lxqt-notificationd-0.14.1/config/translations/lxqt-config-notificationd_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>AdvancedSettings</name>
    <message>
        <location filename="../advancedsettings.ui" line="17"/>
        <source>Sizes</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="25"/>
        <source>Width:</source>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="32"/>
        <location filename="../advancedsettings.ui" line="56"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="49"/>
        <source>Spacing:</source>
        <translation>Odstęp:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="68"/>
        <source>Duration</source>
        <translation>Czas trwania</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="80"/>
        <source>Some notifications set their own on-screen duration.</source>
        <translation>Niektóre powiadomienia mają swój własny czas trwania.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="92"/>
        <source>Default duration:</source>
        <translation>Domyślny czas trwania:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="99"/>
        <source> sec</source>
        <translation> sek</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="127"/>
        <source>Unattended Notifications</source>
        <translation>Pominięte powiadomienia</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="135"/>
        <source>How many to save:</source>
        <translation>Ile zapisać:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="149"/>
        <location filename="../advancedsettings.ui" line="159"/>
        <source>Application name is on the top of notification.</source>
        <translation>Nazwa aplikacji jest na górze powiadomienia.</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="152"/>
        <source>Ignore these applications:</source>
        <translation>Ignoruj te aplikacje:</translation>
    </message>
    <message>
        <location filename="../advancedsettings.ui" line="162"/>
        <source>app1,app2,app3</source>
        <translation>app1,app2,app3</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Ustawienia ogólne</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Position on screen</source>
        <translation>Pozycja na ekranie</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="56"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
A fallback will be used.</source>
        <translation>&lt;b&gt;Uwaga:&lt;/b&gt; Żadna usługa powiadomień nie jest uruchomiona.
Zostanie użyty zamiennik.</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="59"/>
        <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
These settings won&apos;t have any effect on it!</source>
        <translation>&lt;b&gt;Uwaga:&lt;/b&gt; Inny daemon powiadomień (%1) jest uruchomiony.
Te ustawienia nie będą miały żadnego wpływu na jego działanie!</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="112"/>
        <source>Notification demo </source>
        <translation>Podgląd powiadomienia </translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="113"/>
        <source>This is a test notification.
 All notifications will now appear here on LXQt.</source>
        <translation>To jest testowe powiadomienie.
Wszystkie powiadomienia LXQt będą teraz pojawiać się tutaj.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="41"/>
        <source>Desktop Notifications</source>
        <translation>Powiadomienia ekranowe</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="44"/>
        <source>Basic Settings</source>
        <translation>Ustawienia</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="48"/>
        <source>Advanced Settings</source>
        <translation>Zaawansowane</translation>
    </message>
</context>
</TS>
